copre_result and seqre_result objectsGrid evaluation of copre_result and seqre_result objects
# S3 method for grideval_result
$(obj, name)# S3 method for grideval_result
[[(obj, i)
grideval(obj, grd = NULL, func = "density", nthreads = 1)
# S3 method for copre_result
grideval(obj, grd = NULL, func = "density", nthreads = 1)
# S3 method for seqre_result
grideval(obj, grd = NULL, func = "density", nthreads = 1)
A grideval_result object, which is a matrix with dimension [k, m]
of evaluated sample functions, with the following attributes:
func: The evaluated function.
grid: The grid points on which each of the k rows was evaluated.
args: A copy of the args entry from obj.
A copre_result or seqre_result object.
The name of the attribute to access (i.e. func, grid, or
args).
A numeric vector of sample indices.
For seqre_result objects, a numeric vector of m grid points.
Either 'distribution', 'density', or 'gradient'.
The number of parallel threads to launch with OpenMP.
grideval(copre_result): Grid evaluation method for copre_result objects.
grideval(seqre_result): Grid evaluation method for seqre_result
objects.
$: Attribute access method for grideval_result objects
[[: Subset method for grideval_result objects