A function that samples marginal mixture densities via a marginal Gibbs sampler.
gibbsmix(data, k, b_msr, s_msr, burn = 1000, thin = 150)A seqre_result object.
The data from which to sample predictive distributions.
The number of predictive samples to draw.
A base_measure object.
A seq_measure object.
The number of initial sampling iterations to discard, will be truncated if a non-integer.
The number of sampling iterations to discard between records, will be truncated if a non-integer.
seqre(), seq_measure(), base_measure()