Obtain Moments from a CopRe or SeqRe Result
moment(obj, mom, cntrl = TRUE, grd = NULL)# S3 method for seqre_result
moment(obj, mom, cntrl = TRUE, grd = NULL)
# S3 method for grideval_result
moment(obj, mom, cntrl = TRUE, grd = NULL)
A vector of moment values for each sampled distribution in obj.
A copre_result or seqre_result object.
A numeric scalar indicating the moment to calculate.
A logical value indicating whether the moment should be central
or not. Defaults to TRUE.
A numeric vector of grid values on which the density function
samples in obj should be calculated for trapezoidal integration.
moment(seqre_result): Moment calculation method for seqre_result objects.
moment(grideval_result): Moment calculation method for grideval_result objects.